@@ -1,20 +1,26 @@
-cf_tmle <- function(Task, outcome, ratios, learners, lrnr_folds, full_fits, pb) {
-  out <- list()
-
+cf_tmle <- function(task, outcome, ratios, learners, control, pb) {
+  out <- vector("list", length = length(task$folds))
   ratios <- matrix(t(apply(ratios, 1, cumprod)),
                    nrow = nrow(ratios),
                    ncol = ncol(ratios))
 
-  for (fold in seq_along(Task$folds)) {
+  for (fold in seq_along(task$folds)) {
     out[[fold]] <- future::future({
       estimate_tmle(
-        get_folded_data(Task$natural, Task$folds, fold),
-        get_folded_data(Task$shifted[, Task$trt, drop = F], Task$folds, fold),
-        outcome, Task$node_list$outcome, Task$cens, Task$risk,
-        Task$tau, Task$outcome_type,
-        get_folded_data(ratios, Task$folds, fold)$train,
-        Task$weights[Task$folds[[fold]]$training_set],
-        learners, lrnr_folds, pb, full_fits
+        get_folded_data(task$natural, task$folds, fold),
+        get_folded_data(task$shifted[, unlist(task$trt), drop = F], task$folds, fold),
+        task$trt,
+        outcome,
+        task$node_list$outcome,
+        task$cens,
+        task$risk,
+        task$tau,
+        task$outcome_type,
+        get_folded_data(ratios, task$folds, fold)$train,
+        task$weights[task$folds[[fold]]$training_set],
+        learners,
+        control,
+        pb
       )
     },
     seed = TRUE)
@@ -23,17 +29,18 @@ cf_tmle <- function(Task, outcome, ratios, learners, lrnr_folds, full_fits, pb)
   out <- future::value(out)
 
   list(
-    natural = recombine_outcome(out, "natural", Task$folds),
-    shifted = cbind(recombine_outcome(out, "shifted", Task$folds), Task$natural[["tmp_lmtp_scaled_outcome"]]),
+    natural = recombine_outcome(out, "natural", task$folds),
+    shifted = cbind(recombine_outcome(out, "shifted", task$folds), task$natural[["tmp_lmtp_scaled_outcome"]]),
     fits = lapply(out, function(x) x[["fits"]])
   )
 }
 
-estimate_tmle <- function(natural, shifted, outcome, node_list, cens, risk, tau, outcome_type, ratios, weights, learners, lrnr_folds, pb, full_fits) {
+estimate_tmle <- function(natural, shifted, trt, outcome, node_list, cens,
+                          risk, tau, outcome_type, ratios, weights, learners, control, pb) {
   m_natural_train <- m_shifted_train <- matrix(nrow = nrow(natural$train), ncol = tau)
   m_natural_valid <- m_shifted_valid <- matrix(nrow = nrow(natural$valid), ncol = tau)
 
-  fits <- list()
+  fits <- vector("list", length = tau)
   for (t in tau:1) {
     i  <- censored(natural$train, cens, t)$i
     jt <- censored(natural$train, cens, t)$j
@@ -57,33 +64,33 @@ estimate_tmle <- function(natural, shifted, outcome, node_list, cens, risk, tau,
       learners,
       outcome_type,
       id = natural$train[i & rt,][["lmtp_id"]],
-      lrnr_folds
+      control$.learners_outcome_folds
     )
 
-    if (full_fits) {
+    if (control$.return_full_fits) {
       fits[[t]] <- fit
     } else {
       fits[[t]] <- extract_sl_weights(fit)
     }
 
-    trt_var <- names(shifted$train)[t]
+    if (length(trt) > 1) {
+      trt_t <- trt[[t]]
+    } else {
+      trt_t <- trt[[1]]
+    }
+
     under_shift_train <- natural$train[jt & rt, vars]
-    under_shift_train[[trt_var]] <- shifted$train[jt & rt, trt_var]
+    under_shift_train[, trt_t] <- shifted$train[jt & rt, trt_t]
 
     under_shift_valid <- natural$valid[jv & rv, vars]
-    under_shift_valid[[trt_var]] <- shifted$valid[jv & rv, trt_var]
+    under_shift_valid[, trt_t] <- shifted$valid[jv & rv, trt_t]
 
     m_natural_train[jt & rt, t] <- bound(SL_predict(fit, natural$train[jt & rt, vars]), 1e-05)
     m_shifted_train[jt & rt, t] <- bound(SL_predict(fit, under_shift_train), 1e-05)
     m_natural_valid[jv & rv, t] <- bound(SL_predict(fit, natural$valid[jv & rv, vars]), 1e-05)
     m_shifted_valid[jv & rv, t] <- bound(SL_predict(fit, under_shift_valid), 1e-05)
 
-    wts <- {
-      if (is.null(weights))
-        ratios[i & rt, t]
-      else
-        ratios[i & rt, t] * weights[i & rt]
-    }
+    wts <- ratios[i & rt, t] * weights[i & rt]
 
     fit <- sw(
       glm(
