@@ -59,7 +59,7 @@ test_that("Variables dont exist", {
 
   expect_error(
     lmtp_sub(sim_cens, A, "Y", time_vary = L, cens = cens),
-    "Assertion on 'c(trt, outcome, baseline, unlist(time_vary), cens, id)' failed: Must be a subset of {'L1','A1','C1','L2','A2','C2','Y'}, but has additional elements {'A'}.",
+    "Assertion on 'c(unlist(trt), outcome, baseline, unlist(time_vary), cens, id)' failed: Must be a subset of {'L1','A1','C1','L2','A2','C2','Y'}, but has additional elements {'A'}.",
     fixed = TRUE
   )
 })
@@ -160,7 +160,7 @@ test_that("Contrast assertions", {
     "Assertion on 'fits' failed: Contrasts not implemented for substitution/IPW estimators."
   )
 
-  fit <- lmtp_sdr(sim_cens, A, "Y", time_vary = L, cens = cens, folds = 1)
+  fit <- lmtp_sdr(sim_cens, A, "Y", time_vary = L, cens = cens, folds = 1, mtp = TRUE)
   expect_error(
     lmtp_contrast(fit, ref = c(0.1, 0.2)),
     "Assertion on 'ref' failed: Must either be a single numeric value or another lmtp object."
@@ -171,7 +171,7 @@ test_that("Contrast assertions", {
     "Assertion on 'fits' failed: Objects must be of type 'lmtp'."
   )
 
-  fit <- lmtp_sdr(sim_cens, A, "Y", time_vary = L, cens = cens, folds = 1, outcome_type = "continuous")
+  fit <- lmtp_sdr(sim_cens, A, "Y", time_vary = L, cens = cens, folds = 1, outcome_type = "continuous", mtp = TRUE)
   expect_error(
     lmtp_contrast(fit, ref = 0.1, type = "rr"),
     "Assertion on 'type' failed: 'rr' specified but one or more outcome types are not 'binomial' or 'survival'."
